@@ -1,14 +1,13 @@
 package Test::Code::TidyAll::Plugin::PerlCritic;
 
-use Code::TidyAll::Util qw(write_file);
 use Test::Class::Most parent => 'Test::Code::TidyAll::Plugin';
 
 sub test_main : Tests {
     my $self = shift;
 
-    my $rc_file = $self->{root_dir} . "/perlcriticrc";
+    my $rc_file = $self->{root_dir}->child('perlcriticrc');
+    $rc_file->spew("only = 1\nseverity = 1\n[TestingAndDebugging::RequireUseStrict]\n");
 
-    write_file( $rc_file, "only = 1\nseverity = 1\n[TestingAndDebugging::RequireUseStrict]\n" );
     $self->tidyall(
         source       => 'my $foo = 5\n',
         conf         => { argv => "--profile $rc_file" },
@@ -19,7 +18,7 @@ sub test_main : Tests {
         conf      => { argv => "--profile $rc_file" },
         expect_ok => 1,
     );
-    write_file( $rc_file, "only = 1\nseverity = 1\n[CodeLayout::ProhibitHardTabs]\n" );
+    $rc_file->spew("only = 1\nseverity = 1\n[CodeLayout::ProhibitHardTabs]\n");
     $self->tidyall(
         source    => 'my $foo = 5\n',
         conf      => { argv => "--profile $rc_file" },
@@ -30,7 +29,7 @@ sub test_main : Tests {
         conf         => { argv => "--profile $rc_file --badoption" },
         expect_error => qr/Unknown option: badoption/
     );
-    write_file( $rc_file, "badconfig = 1\n" );
+    $rc_file->spew("badconfig = 1\n");
     $self->tidyall(
         source       => 'my $foo = 5\n',
         conf         => { argv => "--profile $rc_file" },
